# ThreeDSecureDataV2AllOf


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**directory_transaction_id** | **str** | The transaction identifier. | 
**authentication_response** | **str** | The transaction status from the challenge result (not required for frictionless). | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


